@@ -30,7 +30,7 @@ mincore_f(
 	int		argc,
 	char		**argv)
 {
-	off64_t		offset;
+	off64_t		offset, llength;
 	size_t		length;
 	size_t		blocksize, sectsize;
 	void		*start;
@@ -49,12 +49,17 @@ mincore_f(
 				argv[1]);
 			return 0;
 		}
-		length = cvtnum(blocksize, sectsize, argv[2]);
-		if (length < 0) {
+		llength = cvtnum(blocksize, sectsize, argv[2]);
+		if (llength < 0) {
 			printf(_("non-numeric length argument -- %s\n"),
 				argv[2]);
 			return 0;
-		}
+		} else if (llength > (size_t)llength) {
+			printf(_("length argument too large -- %lld\n"),
+				(long long)llength);
+			return 0;
+		} else
+			length = (size_t)llength;
 	} else {
 		return command_usage(&mincore_cmd);
 	}
@@ -108,8 +113,8 @@ mincore_f(
 void
 mincore_init(void)
 {
-	mincore_cmd.name = _("mincore");
-	mincore_cmd.altname = _("mi");
+	mincore_cmd.name = "mincore";
+	mincore_cmd.altname = "mi";
 	mincore_cmd.cfunc = mincore_f;
 	mincore_cmd.argmin = 0;
 	mincore_cmd.argmax = 2;
