@@ -396,26 +396,26 @@ static void blkid_get_topology(
 	if (!tp)
 		goto out_free_probe;
 
-	/*
-	 * Blkid reports the information in terms of bytes, but we want it in
-	 * terms of 512 bytes blocks (just to convert it to bytes later..)
-	 *
-	 * If the reported values are just the normal 512 byte block size
-	 * do not bother to report anything.  It will just causes warnings
-	 * if people specifier larger stripe units or widths manually.
-	 */
-	val = blkid_topology_get_minimum_io_size(tp) >> 9;
-	if (val > 1)
-		*sunit = val;
-	val = blkid_topology_get_optimal_io_size(tp) >> 9;
-	if (val > 1)
-		*swidth = val;
-
 	val = blkid_topology_get_logical_sector_size(tp);
 	*lsectorsize = val;
 	val = blkid_topology_get_physical_sector_size(tp);
 	*psectorsize = val;
 
+	/*
+	 * Blkid reports the information in terms of bytes, but we want it in
+	 * terms of 512 bytes blocks (just to convert it to bytes later..)
+	 *
+	 * If the reported values are the same as the physical sector size
+	 * do not bother to report anything.  It will just cause warnings
+	 * if people specify larger stripe units or widths manually.
+	 */
+	val = blkid_topology_get_minimum_io_size(tp);
+	if (val > *psectorsize)
+		*sunit = val >> 9;
+	val = blkid_topology_get_optimal_io_size(tp);
+	if (val > *psectorsize)
+		*swidth = val >> 9;
+
 	if (blkid_topology_get_alignment_offset(tp) != 0) {
 		fprintf(stderr,
 			_("warning: device is not properly aligned %s\n"),
@@ -707,7 +707,7 @@ validate_ag_geometry(
 {
 	if (agsize < XFS_AG_MIN_BLOCKS(blocklog)) {
 		fprintf(stderr,
-	_("agsize (%lldb) too small, need at least %lld blocks\n"),
+	_("agsize (%lld blocks) too small, need at least %lld blocks\n"),
 			(long long)agsize,
 			(long long)XFS_AG_MIN_BLOCKS(blocklog));
 		usage();
@@ -715,7 +715,7 @@ validate_ag_geometry(
 
 	if (agsize > XFS_AG_MAX_BLOCKS(blocklog)) {
 		fprintf(stderr,
-	_("agsize (%lldb) too big, maximum is %lld blocks\n"),
+	_("agsize (%lld blocks) too big, maximum is %lld blocks\n"),
 			(long long)agsize,
 			(long long)XFS_AG_MAX_BLOCKS(blocklog));
 		usage();
@@ -723,7 +723,7 @@ validate_ag_geometry(
 
 	if (agsize > dblocks) {
 		fprintf(stderr,
-	_("agsize (%lldb) too big, data area is %lld blocks\n"),
+	_("agsize (%lld blocks) too big, data area is %lld blocks\n"),
 			(long long)agsize, (long long)dblocks);
 			usage();
 	}
@@ -1898,7 +1898,7 @@ _("block size %d cannot be smaller than logical sector size %d\n"),
 			fprintf(stderr,
 	_("allowable inode size with %d byte blocks is between %d and %d\n"),
 				blocksize, XFS_DINODE_MIN_SIZE, maxsz);
-		usage();
+		exit(1);
 	}
 
 	/* if lsu or lsunit was specified, automatically use v2 logs */
@@ -1950,7 +1950,7 @@ _("block size %d cannot be smaller than logical sector size %d\n"),
 		}
 	}
 
-	if (discard) {
+	if (discard && !Nflag) {
 		discard_blocks(xi.ddev, xi.dsize);
 		if (xi.rtdev)
 			discard_blocks(xi.rtdev, xi.rtsize);
@@ -2090,25 +2090,6 @@ _("size %s specified for log subvolume is too large, maximum is %lld blocks\n"),
 		nbmblocks = 0;
 	}
 
-	if (dasize) {		/* User-specified AG size */
-		/*
-		 * Check specified agsize is a multiple of blocksize.
-		 */
-		if (agsize % blocksize) {
-			fprintf(stderr,
-		_("agsize (%lld) not a multiple of fs blk size (%d)\n"),
-				(long long)agsize, blocksize);
-			usage();
-		}
-		agsize /= blocksize;
-		agcount = dblocks / agsize + (dblocks % agsize != 0);
-
-	} else if (daflag)	/* User-specified AG count */
-		agsize = dblocks / agcount + (dblocks % agcount != 0);
-	else
-		calc_default_ag_geometry(blocklog, dblocks,
-				ft.dsunit | ft.dswidth, &agsize, &agcount);
-
 	if (!nodsflag) {
 		if (dsunit) {
 			if (ft.dsunit && ft.dsunit != dsunit) {
@@ -2132,6 +2113,26 @@ _("size %s specified for log subvolume is too large, maximum is %lld blocks\n"),
 		}
 	} /* else dsunit & dswidth can't be set if nodsflag is set */
 
+	if (dasize) {		/* User-specified AG size */
+		/*
+		 * Check specified agsize is a multiple of blocksize.
+		 */
+		if (agsize % blocksize) {
+			fprintf(stderr,
+		_("agsize (%lld) not a multiple of fs blk size (%d)\n"),
+				(long long)agsize, blocksize);
+			usage();
+		}
+		agsize /= blocksize;
+		agcount = dblocks / agsize + (dblocks % agsize != 0);
+
+	} else if (daflag) {	/* User-specified AG count */
+		agsize = dblocks / agcount + (dblocks % agcount != 0);
+	} else {
+		calc_default_ag_geometry(blocklog, dblocks,
+				dsunit | dswidth, &agsize, &agcount);
+	}
+
 	/*
 	 * If dsunit is a multiple of fs blocksize, then check that is a
 	 * multiple of the agsize too
@@ -2174,9 +2175,12 @@ _("size %s specified for log subvolume is too large, maximum is %lld blocks\n"),
 				if (nodsflag) {
 					dsunit = dswidth = 0;
 				} else {
-					fprintf(stderr,
-_("Allocation group size (%lld) is not a multiple of the stripe unit (%d)\n"),
-						(long long)agsize, dsunit);
+					/*
+					 * agsize is out of bounds, this will
+					 * print nice details & exit.
+					 */
+					validate_ag_geometry(blocklog, dblocks,
+							    agsize, agcount);
 					exit(1);
 				}
 			}
@@ -2588,8 +2592,17 @@ an AG size that is one stripe unit smaller, for example %llu.\n"),
 			 */
 			be32_add_cpu(&arec->ar_startblock, logblocks);
 		}
+		/*
+		 * Calculate the record block count and check for the case where
+		 * the log might have consumed all available space in the AG. If
+		 * so, reset the record count to 0 to avoid exposure of an invalid
+		 * record start block.
+		 */
 		arec->ar_blockcount = cpu_to_be32(agsize - 
 					be32_to_cpu(arec->ar_startblock));
+		if (!arec->ar_blockcount)
+			block->bb_numrecs = 0;
+
 		libxfs_writebuf(buf, LIBXFS_EXIT_ON_FAILURE);
 
 		/*
@@ -2621,8 +2634,17 @@ an AG size that is one stripe unit smaller, for example %llu.\n"),
 			}
 			be32_add_cpu(&arec->ar_startblock, logblocks);
 		}
+		/*
+		 * Calculate the record block count and check for the case where
+		 * the log might have consumed all available space in the AG. If
+		 * so, reset the record count to 0 to avoid exposure of an invalid
+		 * record start block.
+		 */
 		arec->ar_blockcount = cpu_to_be32(agsize - 
 					be32_to_cpu(arec->ar_startblock));
+		if (!arec->ar_blockcount)
+			block->bb_numrecs = 0;
+
 		libxfs_writebuf(buf, LIBXFS_EXIT_ON_FAILURE);
 
 		/*
@@ -2877,13 +2899,16 @@ usage( void )
 /* data subvol */	[-d agcount=n,agsize=n,file,name=xxx,size=num,\n\
 			    (sunit=value,swidth=value|su=num,sw=num),\n\
 			    sectlog=n|sectsize=num\n\
+/* force overwrite */	[-f]\n\
 /* inode size */	[-i log=n|perblock=n|size=num,maxpct=n,attr=0|1|2,\n\
 			    projid32bit=0|1]\n\
+/* no discard */	[-K]\n\
 /* log subvol */	[-l agnum=n,internal,size=num,logdev=xxx,version=n\n\
 			    sunit=value|su=num,sectlog=n|sectsize=num,\n\
 			    lazy-count=0|1]\n\
 /* label */		[-L label (maximum 12 characters)]\n\
 /* naming */		[-n log=n|size=num,version=2|ci]\n\
+/* no-op info only */	[-N]\n\
 /* prototype file */	[-p fname]\n\
 /* quiet */		[-q]\n\
 /* realtime subvol */	[-r extsize=num,size=num,rtdev=xxx]\n\
